@@ -130,6 +130,11 @@ typedef struct
 	int			offset;			/* offset of field in result struct */
 } relopt_parse_elt;
 
+typedef struct
+{
+	int hasPgOpts;
+	char relkind;
+} ExtraRelOptionParams;
 
 /*
  * These macros exist for the convenience of amoptions writers (but consider
@@ -260,7 +265,7 @@ extern void add_string_reloption(bits32 kinds, const char *name, const char *des
 
 extern Datum transformRelOptions(Datum oldOptions, List *defList,
 					const char *namspace, char *validnsps[],
-					bool ignoreOids, bool isReset, int *haspgopts);
+					bool ignoreOids, bool isReset, ExtraRelOptionParams *extra);
 extern List *untransformRelOptions(Datum options);
 extern bytea *extractRelOptions(HeapTuple tuple, TupleDesc tupdesc,
 				  amoptions_function amoptions);
@@ -287,5 +292,5 @@ extern LOCKMODE AlterTableGetRelOptionsLockLevel(List *defList);
 
 extern const char *AvailableRemoteStorageOption(bool can_alter);
 extern bool IsRemoteStorageOption(const char *opt);
-
+extern bool IsKunlunCNStorageOption(const char *opt);
 #endif							/* RELOPTIONS_H */
