@@ -30,11 +30,14 @@ extern Oid find_root_base_type(Oid typid0);
 extern void update_colnames_indices(Relation attrelation, Relation targetrelation,
 	int attnum, const char *oldattname, const char *newattname);
 
-extern const char* atsubcmd(AlterTableCmd *subcmd);
-
 extern void build_column_data_type(StringInfo str, Oid typid,
 	int32 typmod, Oid collation);
 
 extern bool front_end_is_mysql();
+extern char*produce_empty_geom_hexstr(Oid typid, int32 typmod, bool intrinsic, bool*need_free);
+extern bool is_geometry_type(Oid typid, bool*intrinsic);
+extern void print_default_value(Relation rel, int attrnum, StringInfo str);
 
+extern RangeTblEntry*create_minimal_rte(Relation relation);
+extern bool serialize_column_default_valstr(Relation rel, int attrnum, StringInfo str, bool val_only);
 #endif /* !REMOTE_META_H */
