@@ -24,6 +24,7 @@ typedef struct RawColumnDefault
 	AttrNumber	attnum;			/* attribute to attach default to */
 	Node	   *raw_default;	/* default value (untransformed parse tree) */
 	bool		missingMode;	/* true if part of add column processing */
+	char 		generated;
 } RawColumnDefault;
 
 typedef struct CookedConstraint
@@ -116,7 +117,8 @@ extern Node *cookDefault(ParseState *pstate,
 			Node *raw_default,
 			Oid atttypid,
 			int32 atttypmod,
-			const char *attname);
+			const char *attname,
+			char attgenerated);
 
 extern void DeleteRelationTuple(Oid relid);
 extern void DeleteAttributeTuples(Oid relid);
@@ -162,5 +164,5 @@ extern void ModifyRelationShardId(Oid relid, Oid shardid);
  *  Modify the shard option of all relations, used when restore data into a
  *  newly created cluster which with different shards.
  */
-extern void ModifyAllRelationShardIds(List *from, List *to);
+extern size_t ModifyAllRelationShardIds(List *from, List *to);
 #endif							/* HEAP_H */
