@@ -397,9 +397,15 @@ DECLARE_UNIQUE_INDEX(pg_mysql_collation_mapping_mysql_coll_name_idx, 6679, on pg
 DECLARE_UNIQUE_INDEX(pg_proc_map_proname_args_nsp_index, 7000, on pg_proc_map using btree(proname name_ops, proargtypes oidvector_ops, pronamespace oid_ops));
 #define ProcedureMapNameArgsNspIndexId 7000
 
+DECLARE_UNIQUE_INDEX(pg_proc_map_oid_index, 7007, on pg_proc_map using btree(oid oid_ops));
+#define ProcMapOidIndexId	7007
+
 DECLARE_UNIQUE_INDEX(pg_type_map_typname_nsp_index,7001, on pg_type_map using btree(typname name_ops, typnamespace oid_ops));
 #define TypeMapNameNspIndexId	7001
 
+DECLARE_UNIQUE_INDEX(pg_type_map_oid_index, 7006, on pg_type_map using btree(oid oid_ops));
+#define TypeMapOidIndexId	7006
+
 DECLARE_UNIQUE_INDEX(pg_tablegroup_tgname_index, 7002, on pg_tablegroup using btree(tgname name_ops));
 #define TableGroupNameIndexId 7002
 
@@ -409,4 +415,10 @@ DECLARE_UNIQUE_INDEX(pg_tablegroup_oid_index, 7003, on pg_tablegroup using btree
 DECLARE_UNIQUE_INDEX(pg_database_name_map_index, 7004, on pg_database_name_map using btree(src_datname name_ops, src_nspname name_ops));
 #define DatabaseNameMapIndexId 7004
 
+DECLARE_UNIQUE_INDEX(pg_database_name_map_dest_dbname_index, 3431, on pg_database_name_map using btree(dst_datname name_ops));
+#define DatabaseNameMapDestDbnameIndexId 3431
+
+DECLARE_UNIQUE_INDEX(pg_mysql_srs_basics_index, 7005, on pg_mysql_srs_basics using btree(srid oid_ops));
+#define MySQLSRSBasicsIndexId 7005
+
 #endif							/* INDEXING_H */
