@@ -21,17 +21,17 @@
 #include "parser/parse_node.h"
 #include "storage/relfilenode.h"
 
+
 /* Hook for plugins to get control in nextval */
 typedef int64_t (*Nextval_hook_type)(Relation seqrel, bool *finished);
 typedef void (*Setval_hook_type)(Relation seqrel,
-								 int64_t val,
-								 bool called,
-								 bool *finished);
+									int64_t val,
+									bool called,
+									bool *finished);
 
 extern PGDLLIMPORT Nextval_hook_type Nextval_hook;
 extern PGDLLIMPORT Setval_hook_type Setval_hook;
 
-
 typedef struct FormData_pg_sequence_data
 {
 	int64		last_value;
@@ -75,5 +75,7 @@ extern void seq_redo(XLogReaderState *rptr);
 extern void seq_desc(StringInfo buf, XLogReaderState *rptr);
 extern const char *seq_identify(uint8 info);
 extern void seq_mask(char *pagedata, BlockNumber blkno);
-
+extern int64_t get_last_insert_id(bool for_session_status);
+extern void ResetLastInsertId(void);
+extern void ResetLastInsertIdStatus(void);
 #endif							/* SEQUENCE_H */
