@@ -291,6 +291,7 @@ typedef enum NodeTag
 	T_Float,
 	T_String,
 	T_BitString,
+	T_HexString,
 	T_Null,
 
 	/*
@@ -345,6 +346,7 @@ typedef enum NodeTag
 	T_LoadStmt,
 	T_CreateDomainStmt,
 	T_CreatedbStmt,
+	T_DbNameMappingStmt,
 	T_DropdbStmt,
 	T_VacuumStmt,
 	T_ExplainStmt,
@@ -429,7 +431,12 @@ typedef enum NodeTag
 	T_ShowSchemasStmt,
 	T_ShowTablesStmt,
 	T_ShowTableStatusStmt,
+	T_ShowColumnsStmt,
+	T_ShowCreateDBStmt,
+	T_ShowCreateSchemaStmt,
 	T_ShowCreateTableStmt,
+	T_ShowIndexStmt,
+	T_DescTableStmt,
 	T_ShowProcessListStmt,
 	T_SendShardStmt,
 	T_FetchMySQLVarStmt,
@@ -437,7 +444,12 @@ typedef enum NodeTag
 	T_ShowCollationStmt,
 	T_ShowCharsetStmt,
 	T_MultiVariableSetStmt,
+	T_OptimizeStmt,
     T_ShowMemoryStmt,
+	T_ShowStatusStmt,
+	T_CreateTableGroupStmt,
+	T_AlterTableGroupStmt,
+	T_DropTableGroupStmt,
 
 	/*
 	 * TAGS FOR PARSE TREE NODES (parsenodes.h)
@@ -495,7 +507,7 @@ typedef enum NodeTag
 	T_PartitionRangeDatum,
 	T_PartitionCmd,
 	T_VacuumRelation,
-
+	T_StartTxnSnapshot,
 	/*
 	 * TAGS FOR REPLICATION GRAMMAR PARSE NODES (replnodes.h)
 	 */
