@@ -18,8 +18,10 @@
 
 #include "postgres.h"
 #include "nodes/plannodes.h"
-
-
+#include "nodes/parsenodes.h"
+#include "nodes/remotenodes.h"
+struct PlannerInfo;
+struct RemoteAggPath;
 /*
   An edge of *pptr pointing to rs, we may later add a Material node M so that
   *pptr->M->rs. Each edge has one and only one such object, upper nodes may
@@ -49,7 +51,32 @@ typedef struct ShardRemoteScanRef
 	struct ShardRemoteScanRef *next; // for next shard
 } ShardRemoteScanRef;
 
+
+/*
+  dzw: push down SET operations if setopr's left&right RS nodes are on the
+  same shard. We combine a subtree of SETops of same operation
+  (UNION/INTERSECT/EXCEPT) in the same RSO node, and use rso_plans to refer to
+  these RS/RJ/RSO plans; and use RSO.plan.left/right_tree to refer to other
+  RSOs(of different setopr type) or other nodes.
+  SET operations to be pushed down don't need optimization in computing node,
+  so we should use the parse nodes to produce RSOPath nodes and use them to
+  produce the RSO subtree.
+
+  SetOperation is a type of parser module but we do need it so move this type
+  here to avoid poluting plannodes.h by #including parsernodes.h.
+*/
+typedef struct RemoteSetOp
+{
+	Plan		plan;
+	SetOperation	rso_setop;
+	Oid				rso_shardid;
+	List			*rso_plans;
+} RemoteSetOp;
+
+
 extern ShardRemoteScanRef *dupShardRemoteScanRefs(ShardRemoteScanRef *src);
 extern void materialize_conflicting_remotescans(PlannedStmt *pstmt);
-extern bool ReleaseShardConnection(PlanState *ps);
+extern List *extract_remote_plan(Plan *plan, bool get_all_rj);
+extern bool fix_tuple_resname_with_tlist(List *tlist, PlanState *planstate);
+
 #endif // !PLAN_REMOTE_H
