@@ -31,6 +31,7 @@ PG_KEYWORD("absolute", ABSOLUTE_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("access", ACCESS, UNRESERVED_KEYWORD)
 PG_KEYWORD("action", ACTION, UNRESERVED_KEYWORD)
 PG_KEYWORD("add", ADD_P, UNRESERVED_KEYWORD)
+PG_KEYWORD("adddate", ADDDATE, COL_NAME_KEYWORD)
 PG_KEYWORD("admin", ADMIN, UNRESERVED_KEYWORD)
 PG_KEYWORD("after", AFTER, UNRESERVED_KEYWORD)
 PG_KEYWORD("aggregate", AGGREGATE, UNRESERVED_KEYWORD)
@@ -77,6 +78,7 @@ PG_KEYWORD("chain", CHAIN, UNRESERVED_KEYWORD)
 PG_KEYWORD("char", CHAR_P, COL_NAME_KEYWORD)
 PG_KEYWORD("character", CHARACTER, COL_NAME_KEYWORD)
 PG_KEYWORD("characteristics", CHARACTERISTICS, UNRESERVED_KEYWORD)
+PG_KEYWORD("charset", CHARSET, TYPE_FUNC_NAME_KEYWORD)
 PG_KEYWORD("check", CHECK, RESERVED_KEYWORD)
 PG_KEYWORD("checkpoint", CHECKPOINT, UNRESERVED_KEYWORD)
 PG_KEYWORD("class", CLASS, UNRESERVED_KEYWORD)
@@ -121,6 +123,8 @@ PG_KEYWORD("cycle", CYCLE, UNRESERVED_KEYWORD)
 PG_KEYWORD("data", DATA_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("database", DATABASE, UNRESERVED_KEYWORD)
 PG_KEYWORD("databases", DATABASES, UNRESERVED_KEYWORD)
+PG_KEYWORD("date_add", DATE_ADD, COL_NAME_KEYWORD)
+PG_KEYWORD("date_sub", DATE_SUB, COL_NAME_KEYWORD)
 PG_KEYWORD("datetime", DATETIME, COL_NAME_KEYWORD)
 PG_KEYWORD("day", DAY_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("deallocate", DEALLOCATE, UNRESERVED_KEYWORD)
@@ -132,11 +136,12 @@ PG_KEYWORD("defaults", DEFAULTS, UNRESERVED_KEYWORD)
 PG_KEYWORD("deferrable", DEFERRABLE, RESERVED_KEYWORD)
 PG_KEYWORD("deferred", DEFERRED, UNRESERVED_KEYWORD)
 PG_KEYWORD("definer", DEFINER, UNRESERVED_KEYWORD)
-PG_KEYWORD("delete", DELETE_P, UNRESERVED_KEYWORD)
+PG_KEYWORD("delete", DELETE_P, RESERVED_KEYWORD)
 PG_KEYWORD("delimiter", DELIMITER, UNRESERVED_KEYWORD)
 PG_KEYWORD("delimiters", DELIMITERS, UNRESERVED_KEYWORD)
 PG_KEYWORD("depends", DEPENDS, UNRESERVED_KEYWORD)
 PG_KEYWORD("desc", DESC, RESERVED_KEYWORD)
+PG_KEYWORD("describe", DESCRIBE, UNRESERVED_KEYWORD)
 PG_KEYWORD("detach", DETACH, UNRESERVED_KEYWORD)
 PG_KEYWORD("dictionary", DICTIONARY, UNRESERVED_KEYWORD)
 PG_KEYWORD("disable", DISABLE_P, UNRESERVED_KEYWORD)
@@ -223,7 +228,7 @@ PG_KEYWORD("inner", INNER_P, TYPE_FUNC_NAME_KEYWORD)
 PG_KEYWORD("inout", INOUT, COL_NAME_KEYWORD)
 PG_KEYWORD("input", INPUT_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("insensitive", INSENSITIVE, UNRESERVED_KEYWORD)
-PG_KEYWORD("insert", INSERT, UNRESERVED_KEYWORD)
+PG_KEYWORD("insert", INSERT, RESERVED_KEYWORD)
 PG_KEYWORD("instead", INSTEAD, UNRESERVED_KEYWORD)
 PG_KEYWORD("int", INT_P, COL_NAME_KEYWORD)
 PG_KEYWORD("integer", INTEGER, COL_NAME_KEYWORD)
@@ -359,7 +364,7 @@ PG_KEYWORD("real", REAL, COL_NAME_KEYWORD)
 PG_KEYWORD("reassign", REASSIGN, UNRESERVED_KEYWORD)
 PG_KEYWORD("recheck", RECHECK, UNRESERVED_KEYWORD)
 PG_KEYWORD("recursive", RECURSIVE, UNRESERVED_KEYWORD)
-PG_KEYWORD("ref", REF, UNRESERVED_KEYWORD)
+PG_KEYWORD("ref", REF_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("references", REFERENCES, RESERVED_KEYWORD)
 PG_KEYWORD("referencing", REFERENCING, UNRESERVED_KEYWORD)
 PG_KEYWORD("refresh", REFRESH, UNRESERVED_KEYWORD)
@@ -368,7 +373,7 @@ PG_KEYWORD("relative", RELATIVE_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("release", RELEASE, UNRESERVED_KEYWORD)
 PG_KEYWORD("rename", RENAME, UNRESERVED_KEYWORD)
 PG_KEYWORD("repeatable", REPEATABLE, UNRESERVED_KEYWORD)
-PG_KEYWORD("replace", REPLACE, UNRESERVED_KEYWORD)
+PG_KEYWORD("replace", REPLACE, RESERVED_KEYWORD)
 PG_KEYWORD("replica", REPLICA, UNRESERVED_KEYWORD)
 PG_KEYWORD("reset", RESET, UNRESERVED_KEYWORD)
 PG_KEYWORD("restart", RESTART, UNRESERVED_KEYWORD)
@@ -405,6 +410,7 @@ PG_KEYWORD("set", SET, RESERVED_KEYWORD)
 PG_KEYWORD("setof", SETOF, COL_NAME_KEYWORD)
 PG_KEYWORD("sets", SETS, UNRESERVED_KEYWORD)
 PG_KEYWORD("shard", SHARD, UNRESERVED_KEYWORD)
+PG_KEYWORD("shards", SHARDS, UNRESERVED_KEYWORD)
 PG_KEYWORD("share", SHARE, UNRESERVED_KEYWORD)
 PG_KEYWORD("show", SHOW, UNRESERVED_KEYWORD)
 PG_KEYWORD("signed", SIGNED, COL_NAME_KEYWORD)
@@ -425,8 +431,10 @@ PG_KEYWORD("status", STATUS, UNRESERVED_KEYWORD)
 PG_KEYWORD("stdin", STDIN, UNRESERVED_KEYWORD)
 PG_KEYWORD("stdout", STDOUT, UNRESERVED_KEYWORD)
 PG_KEYWORD("storage", STORAGE, UNRESERVED_KEYWORD)
+PG_KEYWORD("stored", STORED, UNRESERVED_KEYWORD)
 PG_KEYWORD("strict", STRICT_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("strip", STRIP_P, UNRESERVED_KEYWORD)
+PG_KEYWORD("subdate", SUBDATE, COL_NAME_KEYWORD)
 PG_KEYWORD("subscription", SUBSCRIPTION, UNRESERVED_KEYWORD)
 PG_KEYWORD("substring", SUBSTRING, COL_NAME_KEYWORD)
 PG_KEYWORD("symmetric", SYMMETRIC, RESERVED_KEYWORD)
@@ -445,6 +453,8 @@ PG_KEYWORD("then", THEN, RESERVED_KEYWORD)
 PG_KEYWORD("ties", TIES, UNRESERVED_KEYWORD)
 PG_KEYWORD("time", TIME, COL_NAME_KEYWORD)
 PG_KEYWORD("timestamp", TIMESTAMP, COL_NAME_KEYWORD)
+PG_KEYWORD("timestampadd", TIMESTAMPADD, COL_NAME_KEYWORD)
+PG_KEYWORD("timestampdiff", TIMESTAMPDIFF, COL_NAME_KEYWORD)
 PG_KEYWORD("tinyblob", TINYBLOB, COL_NAME_KEYWORD)
 PG_KEYWORD("tinyint", TINYINT, COL_NAME_KEYWORD)
 PG_KEYWORD("tinytext", TINYTEXT, COL_NAME_KEYWORD)
@@ -470,7 +480,7 @@ PG_KEYWORD("unlisten", UNLISTEN, UNRESERVED_KEYWORD)
 PG_KEYWORD("unlogged", UNLOGGED, UNRESERVED_KEYWORD)
 PG_KEYWORD("unsigned", UNSIGNED, COL_NAME_KEYWORD)
 PG_KEYWORD("until", UNTIL, UNRESERVED_KEYWORD)
-PG_KEYWORD("update", UPDATE, UNRESERVED_KEYWORD)
+PG_KEYWORD("update", UPDATE, RESERVED_KEYWORD)
 PG_KEYWORD("use", USE, UNRESERVED_KEYWORD)
 PG_KEYWORD("user", USER, RESERVED_KEYWORD)
 PG_KEYWORD("using", USING, RESERVED_KEYWORD)
@@ -489,6 +499,7 @@ PG_KEYWORD("verbose", VERBOSE, TYPE_FUNC_NAME_KEYWORD)
 PG_KEYWORD("version", VERSION_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("view", VIEW, UNRESERVED_KEYWORD)
 PG_KEYWORD("views", VIEWS, UNRESERVED_KEYWORD)
+PG_KEYWORD("virtual", VIRTUAL, UNRESERVED_KEYWORD)
 PG_KEYWORD("volatile", VOLATILE, UNRESERVED_KEYWORD)
 PG_KEYWORD("when", WHEN, RESERVED_KEYWORD)
 PG_KEYWORD("where", WHERE, RESERVED_KEYWORD)
