@@ -13,6 +13,7 @@
 #ifndef ALGOS_H
 #define ALGOS_H
 
+typedef int (*func_cmp_ctx_t)(const void *elem1, const void *elem2, void *ctx);
 typedef int (*func_cmp_t)(const void *elem1, const void *elem2);
 /*
  * Do binary search to find 'key' from [base, base + num_elems), each element's
@@ -21,8 +22,11 @@ typedef int (*func_cmp_t)(const void *elem1, const void *elem2);
  * return the found 'key' element's index in the array, or -1 if not found.
  * return -2 if invalid arguments.
  * */
-int bin_search(const void *key, const void *base, size_t num_elems,
+extern int bin_search(const void *key, const void *base, size_t num_elems,
 	size_t elesz, func_cmp_t cmpf, int *inspos);
 
+extern int bin_search_with_context(const void *key, const void *base,
+	size_t num_elems,
+	size_t elesz, func_cmp_ctx_t cmpf, int *inspos, void *ctx);
 
 #endif
