@@ -33,4 +33,6 @@ extern int my_wildcmp(const CHARSET_INFO *, const char *str, const char *str_end
 extern uint my_strstr(const CHARSET_INFO *, const char *b, size_t b_length,
 					  const char *s, size_t s_length);
 
-#endif
\ No newline at end of file
+extern uint my_strstr_nth(const CHARSET_INFO *, const char *b, size_t b_length,
+					  const char *s, size_t s_length, uint nth);
+#endif
