@@ -62,7 +62,8 @@ def add_computing_nodes(mysql_conn_params, args, config_path, install_ids, intoS
     ha_mode = -1
     data2 = row[2]
     if sys.version_info.major == 3:
-        data2 = data2.decode()
+        if type(data2) is not str:
+            data2 = data2.decode()
     if data2 == 'no_rep':
         ha_mode = 0
     elif data2 == 'mgr':
@@ -75,7 +76,8 @@ def add_computing_nodes(mysql_conn_params, args, config_path, install_ids, intoS
     meta_ha_mode = -1
     data0 = row[0]
     if sys.version_info.major == 3:
-        data0 = data0.decode()
+        if type(data0) is not str:
+            data0 = data0.decode()
     if data0 == 'no_rep':
         meta_ha_mode = 0
     elif data0 == 'mgr':
@@ -87,7 +89,10 @@ def add_computing_nodes(mysql_conn_params, args, config_path, install_ids, intoS
     server_rows = meta_cursor.fetchall()
     idmap = {}
     for server_row in server_rows:
-        idmap[bytes(server_row[1])] = server_row[0]
+        if type(server_row[1]) is str:
+            idmap[server_row[1]] = server_row[0]
+        else:
+            idmap[bytes(server_row[1])] = server_row[0]
 
     meta_cursor0 = meta_conn.cursor(buffered=True, dictionary=True)
 
