@@ -85,7 +85,7 @@ def add_comp_self(install_path, config_template_file, mysql_conn_params, config_
             os.system("su postgres -c 'cd /kunlun && . ./env.sh; cd $PG_DIR/scripts; python2 install_pg.py --config=./%s --install_ids=%d %s' " % (
                 config_path, maxid, valgrindopt))
         else:
-            install_pg.install_pg(config_template_file, install_path, selfobj, args.valgrind)
+            install_pg.install_pg(config_template_file, install_path, selfobj, args.valgrind, args.nopreload)
     conn = checkserver(selfip, args.port, args.user, args.password, 'postgres')
     if conn is None:
         raise Exception("Computing server is not installed correctly, please check the installation!")
@@ -122,6 +122,7 @@ if __name__ == '__main__':
     parser.add_argument('--docker', help="process is in docker container", default=False, action='store_true')
     parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
     parser.add_argument('--valgrind', help="whether to use valgrind", default=False, action='store_true')
+    parser.add_argument('--nopreload', help="whether to avoid setting LD_PRELOAD ", default=False, action='store_true')
 
     args = parser.parse_args()
 
