@@ -8,6 +8,7 @@ import argparse
 import json
 import subprocess
 import common
+from common import my_print
 
 parser = argparse.ArgumentParser(description='create meta tables and initialize them with meta data.')
 parser.add_argument('--config', type=str, help="meta-data shard config file path")
@@ -58,7 +59,7 @@ stmt = "insert into meta_db_nodes(hostaddr, port, user_name, passwd, master_prio
         values(%s, %s, %s, %s, %s, %s, %s, %s, %s, 0, 0, 1, %s)"
 mysql_conn_params['is_primary'] = True
 for node in jscfg:
-    if not node.has_key('nodemgr_bin_path'):
+    if 'nodemgr_bin_path' not in node:
         node['nodemgr_bin_path'] = ''
     role = 'replica'
     if node.get('is_primary', False):
@@ -72,4 +73,4 @@ meta_cursor.close()
 meta_cursor0.close()
 meta_conn.close()
 jsconf.close()
-print "Bootstrapping completed!"
+my_print("Bootstrapping completed!")
