@@ -1,4 +1,4 @@
-#!/bin/env python2
+#!/usr/bin/env python2
 import argparse
 import os
 import sys
@@ -18,6 +18,7 @@ def param_replace(string, rep_dict):
 def prepare_directorys(args):
   global localied_conf_path
   global localied_data_dir
+  global localied_vec_tmpdir
   global localied_work_dir
   localied_install_port_dir = "{ins_prefix}/{pt}".format(ins_prefix=args.install_prefix,pt=args.pg_protocal_port)
   if os.path.exists(localied_install_port_dir):
@@ -31,6 +32,12 @@ def prepare_directorys(args):
     sys.exit(1)
   os.makedirs(localied_data_dir)
   
+  localied_vec_tmpdir = "{dpr}/{pgport}/vec_tmpdir".format(dpr=args.datadir_prefix,pgport=args.pg_protocal_port)
+  #if os.path.exists(localied_vec_tmpdir) and len(os.listdir(localied_vec_tmpdir))!=0:
+  #  sys.stderr.write("Invalid vec tmp dir: {} already exists and is not empty".format(localied_vec_tmpdir))
+  #  sys.exit(1)
+  #os.makedirs(localied_vec_tmpdir)
+
   # copy package to dest
   package_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
   cmd = "cp -r {pkg} {lopr}".format(pkg= package_path,lopr=localied_install_port_dir)
@@ -45,19 +52,63 @@ def init_db(args):
   initcmd = cmd0 + localied_work_dir + '/bin/initdb -D ' + localied_data_dir + ' 2>&1'
   os.system(initcmd) 
 
-def open_single_shard_mode(localied_conf_path):
+def modify_spec_conf(localied_conf_path):
+  var_params = args.var_params
+  
+  var_dict={}
+  if var_params != 'default':
+    var_list = var_params.split(";")
+    for item in var_list:
+      if len(item):
+        tmp = item.split("=")
+        var_dict[tmp[0]] = tmp[1]
+  
   new_content = ""
+  del_list = []
   with open(localied_conf_path, 'r') as f:
     for line in f:
-      if line.startswith('single_shard_mode'):
-        new_content = new_content + 'single_shard_mode = true\n'
+      print(line)
+      if args.single_shard_mode == 'on':
+        if line.startswith('single_shard_mode'):
+          new_content = new_content + 'single_shard_mode = true\n'
+          continue
+      elif args.enable_global_mvcc == 'on':
+        if line.startswith('enable_global_mvcc'):
+          new_content = new_content + 'enable_global_mvcc = true\n'
+          continue
       else:
-        new_content = new_content + line;
+        match_flag = False
+        for key, val in var_dict.items():
+          if line.startswith(key):
+            new_content = new_content + key + ' = ' + val + '\n'
+            del_list.append(key)
+            match_flag = True
+            
+        
+        if match_flag:
+          continue
+
+      new_content = new_content + line;
     
     f.close()
+
+  for item in del_list:
+    del var_dict[item]
   
   with open(localied_conf_path, 'w') as f:
     f.write(new_content)
+    for key, val in var_dict.items():
+      f.write(key + ' = ' + val + '\n')
+    f.close()
+
+def open_pg_extension(localied_conf_path):
+  if os.path.exists(localied_vec_tmpdir) == False:
+    os.makedirs(localied_vec_tmpdir)
+
+  with open(localied_conf_path, 'a') as f:
+    f.write("tornado_cn.enable_custom_planner = true\n")
+    vec_tmpdir = "tornado_cn.data_dir='{tddir}'\n".format(tddir=localied_vec_tmpdir)
+    f.write(vec_tmpdir)
     f.close()
 
 def deal_conf(args):
@@ -79,11 +130,15 @@ def deal_conf(args):
   conf_file = open(localied_conf_path,'w')
   conf_file.write(conf_content)
   conf_file.close()
-  
-  if args.single_shard_mode == 'on':
-    open_single_shard_mode(localied_conf_path)
+    
+  if args.single_shard_mode == 'on' or args.enable_global_mvcc == 'on' or args.var_params != 'default':
+    modify_spec_conf(localied_conf_path)
+  open_pg_extension(localied_conf_path)
 
-  os.system('echo "host all all ' + args.bind_address + '/32 trust" >> ' + localied_data_dir + '/pg_hba.conf')
+  if args.with_hostname:
+    os.system('echo "host all all ' + args.bind_address + ' trust" >> ' + localied_data_dir + '/pg_hba.conf')
+  else:
+    os.system('echo "host all all ' + args.bind_address + '/32 trust" >> ' + localied_data_dir + '/pg_hba.conf')
   os.system('echo "host all all 127.0.0.1/32  trust" >> ' + localied_data_dir + '/pg_hba.conf')
   os.system('echo "host all agent 0.0.0.0/0 reject" >> ' + localied_data_dir + '/pg_hba.conf')
   os.system('echo "host all all 0.0.0.0/0 md5" >> ' + localied_data_dir + '/pg_hba.conf') 
@@ -99,7 +154,7 @@ def boot_postgres(args):
       prefix = "valgrind --leak-check=full --trace-children=yes --undef-value-errors=no "
 
   cmd0 = "export LD_LIBRARY_PATH=" + localied_work_dir + "/lib:$LD_LIBRARY_PATH;"
-  cmd1 = 'export LD_PRELOAD="' + localied_work_dir + '/resources/libjemalloc.so.3.6.0"; ulimit -c unlimited; '
+  cmd1 = 'export LD_PRELOAD="' + localied_work_dir + '/resources/libjemalloc.so"; ulimit -c unlimited; '
   startup_cmd = cmd0 + cmd1 + prefix + localied_work_dir + '/bin/postgres -D ' + localied_data_dir + " > " + pg_logfp + " 2>&1 &"
   ret = os.system(startup_cmd)
   if ret != 0:
@@ -135,7 +190,6 @@ def boot_postgres(args):
   os.system("echo \"" + str(args.pg_protocal_port) + "==>" + localied_data_dir + "\" >> " + list_file)
 
 def rollBackInstallaiton(args):
-
     error_count = 0
     workpath = "{prefix}/{pt}/{prgname}".format(
         prefix=os.path.abspath(args.install_prefix), pt=str(args.pg_protocal_port), prgname=str(args.prog_name)
@@ -202,7 +256,10 @@ if __name__ == "__main__":
   parser.add_argument('--install_prefix',type=str,help="Postgres install prefix",required=True)
   parser.add_argument('--prog_name',type=str,help="Postgres pkg name",required=True)
   parser.add_argument('--single_shard_mode',type=str,help="Postgres single shard mode",required=True)
+  parser.add_argument('--enable_global_mvcc',type=str,help="Postgres enable global mvcc",required=True)
+  parser.add_argument('--var_params',type=str,help="Postgres global variable params",required=True)
   parser.add_argument('--valgrind',type=bool,help="Start Postgresql with valgrind or not",required=False,default=False)
+  parser.add_argument('--with_hostname',type=bool,help="Start Postgresql with hostname",required=False,default=False)
   args= parser.parse_args()
 
   try:
@@ -211,10 +268,10 @@ if __name__ == "__main__":
 
     # do initdb
     init_db(args)
-
+    
     # deal conf
     deal_conf(args)
-
+    
     # boot postgres
     boot_postgres(args)
   except:  
