@@ -101,13 +101,14 @@ CREATE TABLE `db_clusters` (
   `nick_name` varchar(120),
   `owner` varchar(120) NOT NULL,
   `ddl_log_tblname` varchar(120) NOT NULL,
-  `when_created` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
   `business` varchar(120) NOT NULL,
   `memo` text,
-  `status` enum('inuse','deleted') DEFAULT 'inuse',
+  `status` enum('inuse','deleted', 'creating') DEFAULT 'creating',
   `ha_mode` enum('no_rep','mgr','rbr') not null,
   `encrypt_backup` tinyint(1) NOT NULL DEFAULT '0',
   `backup_encrypt_key` varchar(256) DEFAULT NULL,
+  `when_deleted` varchar(24) DEFAULT NULL,
+  `when_created` varchar(24) DEFAULT NULL,
   PRIMARY KEY (`id`),
   UNIQUE KEY `name` (`name`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
@@ -135,7 +136,6 @@ CREATE TABLE `comp_nodes` (
   `port` smallint unsigned NOT NULL,
   `mysql_port` smallint unsigned NOT NULL,
   `db_cluster_id` int unsigned NOT NULL,
-  `when_created` timestamp NULL DEFAULT (now()),
   `user_name` varchar(64) NOT NULL,
   `passwd` varchar(16) NOT NULL,
   `status` enum('creating','inactive','active','deleted','manual_stop') DEFAULT 'creating',
@@ -149,7 +149,8 @@ CREATE TABLE `comp_nodes` (
 
   extra_props text,
   `coldbackup_period` varchar(50) NOT NULL default '01:00:00-02:00:00',
-
+  `when_deleted` varchar(24) DEFAULT NULL,
+  `when_created` varchar(24) DEFAULT NULL,
   PRIMARY KEY (db_cluster_id, `id`),
   UNIQUE KEY `cluster_id_name` (db_cluster_id, `name`),
   FOREIGN KEY (db_cluster_id) references db_clusters(id),
@@ -166,7 +167,6 @@ CREATE TABLE `proxysql_nodes` (
   `hostaddr` varchar(8192) NOT NULL,
   `port` smallint unsigned NOT NULL,
   `db_cluster_id` int unsigned NOT NULL,
-  `when_created` timestamp NULL DEFAULT (now()),
   `user_name` varchar(64) NOT NULL,
   `passwd` varchar(16) NOT NULL,
   `status` enum('creating','inactive','active','deleted','manual_stop') DEFAULT 'creating',
@@ -175,6 +175,8 @@ CREATE TABLE `proxysql_nodes` (
   `max_mem_MB` int unsigned NOT NULL DEFAULT '0',
   `max_conns` int unsigned NOT NULL DEFAULT '0',
   `extra_props` text,
+  `when_deleted` varchar(24) DEFAULT NULL,
+  `when_created` varchar(24) DEFAULT NULL,
   PRIMARY KEY (`db_cluster_id`,`id`),
   UNIQUE KEY `cluster_id_name` (`db_cluster_id`,`name`),
   KEY `svr_node_id` (`svr_node_id`),
@@ -198,14 +200,15 @@ CREATE TABLE `ddl_ops_log_template_table` (
   `user_name` varchar(64) NOT NULL,
   `role_name` varchar(64) NOT NULL,
   `search_path` text NOT NULL,
-  `optype` enum('create','drop','rename','alter','replace', 'remap_shardid', 'add_shard', 'add_node', 'delete_shard', 'delete_node', 'add_computer', 'others') NOT NULL,
+  `optype` enum('create','drop','rename','alter','replace', 'remap_shardid', 'add_shard', 'add_node', 'delete_shard', 'delete_node', 'add_computer', 'rcr_shard','others') NOT NULL,
   `objtype` enum('db','index','matview','partition','schema','seq','table','func','role_or_group','proc','stats','user','view', 'others') NOT NULL,
   `when_logged` timestamp(6) NULL DEFAULT current_timestamp(6),
-  `sql_src` text NOT NULL,
-  `sql_storage_node` text NOT NULL,
+  `sql_src` longtext NOT NULL,
+  `sql_storage_node` longtext NOT NULL,
   `target_shard_id` int unsigned NOT NULL, -- no FK for perf, references shards.id
   `initiator` int unsigned NOT NULL, -- no FK for perf, references comp_nodes.id
   `txn_id` bigint unsigned NOT NULL,
+  `rcr_shard_map` varchar(4096) character set latin1 default '',
   PRIMARY KEY (`id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 /*!40101 SET character_set_client = @saved_cs_client */;
@@ -231,6 +234,8 @@ CREATE TABLE `meta_db_nodes` (
   `replica_delay` int NOT NULL default 0,
   `degrade_conf_time` int NOT NULL default 0,
   `sync_num` smallint unsigned NOT NULL DEFAULT 1,
+  `data_storage_MB` int unsigned NOT NULL DEFAULT '0',
+  `log_storage_MB` int unsigned NOT NULL DEFAULT '0',
   `nodemgr_bin_path` varchar(8192) DEFAULT NULL,
   UNIQUE KEY `id` (`id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
@@ -254,13 +259,15 @@ CREATE TABLE `server_nodes` (
   -- device, in order to achieve high parallel IO.
 
   -- full paths to computing node data dir
-  `comp_datadir` varchar(8192) character set latin1, 
+  `comp_datadir` text,
   -- full paths to store data directories of all computing nodes
-  `datadir` varchar(8192) character set latin1,
+  `datadir` text,
   -- full paths to store binlog dirs of all storage nodes
-  `logdir` varchar(8192) character set latin1,
+  `logdir` text,
   -- full paths to store wal log dirs of all storage nodes
-  `wal_log_dir` varchar(8192) character set latin1,
+  `wal_log_dir` text,
+  -- full path to store keyring files
+  `keyring_dir` text,
   -- there may be multiple storage devices, detailed stats in server_nodes_stats
   -- `total_storage` bigint unsigned NOT NULL, -- in MBs.
   `total_mem` int unsigned DEFAULT 0, -- in MBs
@@ -280,6 +287,7 @@ CREATE TABLE `server_nodes` (
   `machine_type` enum('storage','computer') DEFAULT NULL,
   `port_range` varchar(256) DEFAULT NULL,
   `used_port` text,
+  `update_ts` datetime DEFAULT NULL,
   `installing_port` text,
   PRIMARY KEY (`id`),
   FOREIGN KEY (dc_id) references data_centers(id)
@@ -305,10 +313,10 @@ CREATE TABLE `server_nodes_stats` (
 
 -- connectivity statistics between server nodes
 CREATE TABLE `server_nodes_conn_stats` (
-  `id1` int unsigned NOT NULL , -- server node id
-  `id2` int unsigned NOT NULL , -- server node id
-  rtt_us int unsigned NOT NULL , -- round trip time in microsecs
-  time_diff_us bigint unsigned NOT NULL , -- local time difference in microsecs
+  `id1` varchar(64) NOT NULL , -- server node id
+  `id2` varchar(64) NOT NULL , -- server node id
+  rtt_ms int unsigned NOT NULL , -- round trip time in microsecs
+  time_diff_ms bigint unsigned NOT NULL , -- local time difference in microsecs
   -- app guarantees no pair stored twice.
   PRIMARY KEY(id1, id2)
 )  ENGINE=InnoDB DEFAULT CHARSET=utf8;
@@ -323,7 +331,6 @@ DROP TABLE IF EXISTS `shards`;
 CREATE TABLE `shards` (
   `id` int unsigned NOT NULL AUTO_INCREMENT,
   `name` varchar(64) NOT NULL,
-  `when_created` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
   `num_nodes` smallint unsigned NOT NULL,
   `space_volumn` bigint unsigned NOT NULL DEFAULT '0',
   `num_tablets` int unsigned NOT NULL DEFAULT '0',
@@ -338,6 +345,8 @@ CREATE TABLE `shards` (
   `degrade_conf_time` int NOT NULL default 0,
   `status` enum('inuse','deleted') DEFAULT 'inuse',
   `coldbackup_period` varchar(50) NOT NULL default '01:00:00-02:00:00',
+  `when_deleted` varchar(24) DEFAULT NULL,
+  `when_created` varchar(24) DEFAULT NULL,
   PRIMARY KEY (`id`),
   UNIQUE KEY `name` (db_cluster_id, `name`),
   FOREIGN KEY (db_cluster_id)  references db_clusters(id)
@@ -361,9 +370,8 @@ CREATE TABLE `shard_nodes` (
   `shard_id` int unsigned NOT NULL,
   `db_cluster_id` int unsigned NOT NULL,
   `svr_node_id` int unsigned NOT NULL,
-  `when_created` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
   `master_priority` smallint NOT NULL default 1,
-  `status` enum('creating','inactive','active','deleted','manual_stop') DEFAULT 'creating',
+  `status` enum('creating','inactive','active','deleted','manual_stop','peer_isolate') DEFAULT 'creating',
 
   -- resource limits, 0 means unlimited
   cpu_cores smallint unsigned NOT NULL default 0,
@@ -383,8 +391,10 @@ CREATE TABLE `shard_nodes` (
   `member_state` enum('source','replica') DEFAULT 'replica',
   `replica_delay` int NOT NULL default 0,
   `backup_node` enum ('OFF', 'ON') DEFAULT 'OFF',
-
+  `when_deleted` varchar(24) DEFAULT NULL,
+  `when_created` varchar(24) DEFAULT NULL,
   PRIMARY KEY (`id`),
+  CONSTRAINT `shard_nodes_chk_1` CHECK (((`ro_weight` > 0) and (`ro_weight` < 100))),
   FOREIGN KEY (db_cluster_id) references db_clusters(id),
   FOREIGN KEY (svr_node_id) references server_nodes(id),
   FOREIGN KEY (shard_id) references shards(id)
@@ -414,8 +424,8 @@ CREATE PROCEDURE `append_ddl_log_entry`(
   obj_type varchar(16),
   op_type varchar(16),
   cur_opid bigint unsigned,
-  sql_src mediumtext,
-  sql_src_sn text,
+  sql_src longtext,
+  sql_src_sn longtext,
   target_shardid int unsigned,
   initiator_id int unsigned,
   txn_id bigint unsigned,
@@ -438,9 +448,11 @@ BEGIN
     set @initiator_id = initiator_id;
     set @txn_id = txn_id;
 
-    if COALESCE(IS_USED_LOCK('DDL'), 0) != CONNECTION_ID() then
+    set @ddl_holder = COALESCE(IS_USED_LOCK('DDL'), 0);
+
+    if @ddl_holder != CONNECTION_ID() then
       SIGNAL SQLSTATE '45000'
-        SET MESSAGE_TEXT = 'DDL lock is hold by current session';
+        SET MESSAGE_TEXT = 'DDL lock is NOT held by current session.';
     end if;
 
     SET @sql = CONCAT(
@@ -517,7 +529,7 @@ create table cluster_shard_backup_restore_log (
 	shard_node_id int unsigned not null,
 	optype enum('backup', 'restore') not null,
 	-- by default NULL and app define place under cluster_backups.backup_addr
-	shard_backup_path varchar(8192) character set latin1,
+	shard_backup_path text,
 	status enum('not_started', 'ongoing', 'done', 'failed') not null default 'not_started',
 	-- extra info for expanding 
 	memo text default null,
@@ -622,6 +634,7 @@ CREATE TABLE `cluster_mgr_nodes` (
 	`port` int unsigned DEFAULT NULL,
 	`raft_port` int unsigned DEFAULT NULL,
 	`prometheus_port` int unsigned DEFAULT NULL,
+	`update_ts` datetime DEFAULT NULL,
 	`member_state` enum('source','replica') DEFAULT 'replica',
 	PRIMARY KEY (`id`)
 ) ENGINE=InnoDB DEFAULT charset=utf8;
@@ -726,7 +739,7 @@ CREATE TABLE `cluster_logicalbackup_record` (
   `execute_host` varchar(128) DEFAULT NULL,
   `job_id` varchar(128) DEFAULT NULL,
   `backup_time` timestamp NULL DEFAULT (now()),
-  `backup_state` enum('done','failed') CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_as_cs NOT NULL DEFAULT 'failed',
+  `backup_state` enum('done','failed') CHARACTER SET latin1 NOT NULL DEFAULT 'failed',
   `backup_info` text,
   PRIMARY KEY (`id`)
 )ENGINE=InnoDB;
@@ -772,7 +785,10 @@ create table `cluster_rcr_infos` (
 	`status` enum('creating','running','deleted','manual_stop','manual_rcrsw') DEFAULT 'creating',
 	`conf_delay_sync` int NOT NULL DEFAULT '0',
 	`sync_host_delay` int NOT NULL DEFAULT '0',
-	`replica_delay` int NOT NULL DEFAULT '0',
+	`slave_replica_delay` int NOT NULL DEFAULT '0',
+	`double_sync` int NOT NULL DEFAULT '0',
+	`master_replica_delay` int NOT NULL DEFAULT '0',
+	`smap_version` int NOT NULL DEFAULT '1',
 	`when_created` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
 	primary key(`id`)
 );
@@ -790,4 +806,23 @@ create table `cluster_rcr_meta_sync` (
 	`update_ts` varchar(16) default '',
 	primary key(`id`)
 );
+
+DROP TABLE IF EXISTS `global_var_setting`;
+create table `global_var_setting` (
+       `cluster_id` int not null,
+       `varname` varchar(64) not null,
+       `owner_sys` enum('computing_node','storage_node') not null,
+       `value` varchar(256) not null,
+       `old_value` varchar(256),
+       `ts` timestamp default now(),
+       primary key(`cluster_id`, `varname`, `owner_sys`)
+) ENGINE=InnoDB;
+
+DROP TABLE IF EXISTS `cluster_variable_config`;
+CREATE TABLE `cluster_variable_config` (
+  `name` varchar(256) NOT NULL,
+  `node_type` enum('storage','computer') NOT NULL,
+  `var_range` text,
+  PRIMARY KEY (`name`,`node_type`)
+) ENGINE=InnoDB;
 -- Dump completed on 2020-01-04 11:14:45
