@@ -1126,6 +1126,14 @@ LANGUAGE INTERNAL
 STRICT STABLE
 PARALLEL RESTRICTED
 AS 'now_scale';
+
+CREATE OR REPLACE FUNCTION
+  sysdate(scale int4 DEFAULT 0)
+RETURNS timestamp
+LANGUAGE INTERNAL
+STRICT STABLE
+PARALLEL RESTRICTED
+AS 'sysdate';
 --
 -- The default permissions for functions mean that anyone can execute them.
 -- A number of functions shouldn't be executable by just anyone, but rather
